import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeTableau10,
} from 'd3';

const svg = select("svg");
const width = window.innerWidth;
const height = window.innerHeight;
const csvUrl =
 'https://gist.githubusercontent.com/SureshJohnWesly11/725dd49759acd18ee0ca7862f9b4a1c2/raw/64f64c3fdbbf141ba51d9a6d31abc488d8aa7da5/olympic-data.csv';

//render the data present in the olympics dataset
const render = data => {
  const pieData = pie().sort(null).value(d=>d.total_medals)(data);
  const colors = scaleOrdinal(schemeTableau10);
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(180)
  	.padAngle(0)
  	.padRadius(0);
  
  //arc is generated for each element in pie chart
  const arcGenerator = d3.arc()
  .innerRadius(0)
  .outerRadius(250);
  
  //append the olympics data
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  
  //colors is atatched with each and every element
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.total_medals))
  	.on("mouseover", d => console.log(d.data.total_medals));
  
  //value of each element is attached here
  sections
    .enter()
    .append('text')
    .text(d => d.data.total_medals)
    .attr("transform", function(d) { return "translate(" + arcGenerator.centroid(d) + ")";  })
    .style("text-anchor", "middle")
  	.style('fill', 'black')
    .style("font-size", 15);
  
  
  //piechart is created 
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  //square boxes representing colors of each country is created here
  legend.append("rect").attr("width",22).attr("height",25).attr("x", 38)
  	.attr("y", -30)
  	.attr("fill", d => colors(d.data.total_medals));
  //Add country names to legend
  legend.append("text")
  	.attr("x", 68)
  	.attr("y", -10)
  	.attr("class","legend_text")
  	.text(d => d.data.Country);
  //Add number of medals of each country to legend
  legend.append("text")
  	.attr("x", 300)
  	.attr("y", -10)
  	.attr("class","legend_value")
  	.text(d=>d.data.total_medals);
}

//Load and display 2020 summer olympics report
csv(csvUrl).then(csvData => {
    csvData.sort((data1, data2) => data2.total_medals-data1.total_medals);
    if (csvData) {
      //only 10 records selected for plotting
      render(csvData.slice(0, 10));
    }
});


